

c     ********************
c     General description:
c     *********************

c     The subroutine "write_nc_intgr_header" includes
c      * a new integer variable (of type SHORT or LONG)
c          on the file with netCDF ID 'nc_id'
c      * a  string  attribute "long_name"    (from 'name.inc')
c      * a  string  attribute "units"        (from 'name.inc')
c      * a  float   attribute "scale_factor" (implicitely from 'specs.inc')
c      * a  float   attribute "add_offset"   (implicitely from 'specs.inc')
c      * an integer attribute "missing_value"


c     ***********************
c     Input/output variables:
c     ***********************

c      variable       (s)  - name of the variable that will be included,
c                             must match one of the names in 'var_name'
c                             on 'name.inc'
c      int_type       (i)  - type of integer variable (NF_SHORT or NF_INT)
c      dim_options    (i)  - no. of sets of different (x,y,z,t)-dimensions
c      var_n_dim      (iA) - no. of dimensions for the various
c                             'dim_options' dimensional combinations
c      var_dim_ids    (iA) - netCDF IDs for the various dimensional
c                             combinations
c      offset         (rA) - value (single value array)
c                             for the attribute "add_offset"
c      scale          (rA) - value (single value array)
c                             for the attribute "scale_factor"
c      var_id         (i)  - output, netCDF variable ID

c     Above:
c      i  - integer variable [ 4 byte, aka. "long" ]
c      s  - string           [ character*(*) ]
c      iA - integer array    [ 4 byte, aka. "long" ]
c      rA - real array       [ 4 byte, aka. "float" ]


      subroutine write_nc_intgr_header(variable,int_type,dim_options,
     >                                 var_n_dim,var_dim_ids,
     >                                 offset,scale,var_id)


      include 'netcdf.inc'
      include 'id.inc'
      include 'name.inc'
      include 'specs.inc'

c     Input:
      integer int_type,dim_options,var_n_dim(dim_options),
     >        var_dim_ids(4,dim_options)
      real offset(1),scale(1)
      character*(*) variable

c     Output:
      integer var_id

c     Local:
      integer size,unit_size,long_name_size,no,nc_status,
     >        dimension_option
      logical got_it
      character*20 unit,temp_name
      character*40 long_name

c     Function:
      integer str_len

c     Check 'int_type':
      if (int_type .ne. NF_SHORT .and. int_type .ne. NF_INT) go to 999

c     Find variable no. on 'name.inc':
      size = str_len(variable)
      no = 0
      got_it = .false.
      do while (no .lt. no_var_name .and. .not. got_it)
         no = no + 1
         temp_name = var_name(no)
         if (variable(1:size) .eq. temp_name(1:var_name_length(no)))
     >      got_it = .true.
      end do
      if (.not. got_it) go to 998


c     --- START preparations ---

c     Set 'unit':
      if (variable(1:size) .eq. 'level') then
         unit = level_unit(leveltype)
         long_name = var_level_name(leveltype)
      else
         unit = var_unit(no)
         long_name = var_long_name(no)
      end if
      unit_size = str_len(unit)
      long_name_size = str_len(long_name)

      if (variable(1:size) .eq. 'lon' .or.
     >    variable(1:size) .eq. 'lat') then
         if (sphere_on) then
            if (variable(1:size) .eq. 'lon') then
               dimension_option = 1
            else
               dimension_option = 2
            end if
         else
            dimension_option = 6
         end if
      else
         dimension_option = var_dimension(no)
      end if

c     --- END preparations ---


c     Define variable:
      nc_status = NF_DEF_VAR(nc_id, variable(1:size), int_type,
     >                       var_n_dim(dimension_option), 
     >                       var_dim_ids(1,dimension_option), var_id)
      if (nc_status .ne. NF_NOERR) call handle_err(nc_status,801)

c     Specify attributes:
      call nc_char_attrib(var_id, 'long_name',
     >                    long_name(1:long_name_size), variable(1:size))
      call nc_char_attrib(var_id, 'units',
     >                    unit(1:unit_size), variable(1:size))
      call nc_dims(var_id, scale, offset, variable(1:size))
      if (int_type .eq. NF_SHORT) then
         call nc_miss_val_i2(var_id, variable(1:size))
      else
         call nc_miss_val_i4(var_id, variable(1:size))
      end if

      write(*,*)' Included variable: ',variable(1:size),' / ',
     >                                 long_name(1:long_name_size)

      go to 1000

 998  write(*,*)
      write(*,*)'Error in the subroutine "write_nc_intgr_header".'
      write(*,*)' The variable name given: ',variable(1:size),
     >          ' is not implemented.'
      write(*,*)' (See the file "name.inc" for a list of implemented ',
     >          ' variables; as "var_name".)'
      write(*,*)'Terminating.'
      write(*,*)
      stop

 999  write(*,*)
      write(*,*)'Error in the subroutine "write_nc_intgr_header".'
      write(*,*)' Unknown type of variable: ',int_type
      write(*,*)' Known types: ',NF_SHORT,' (NF_SHORT); ',
     >                           NF_INT,  ' (NF_INTT)'
      write(*,*)'Terminating.'
      write(*,*)
      stop

 1000 return
      end
