
c     Subroutines on this file:
c      nc_char_attrib   - writes one character netCDF attribute
c      nc_miss_val_i2   - includes  the numeric attributes 'missing_value'
c                         of type integer*2 (short)
c      nc_miss_val_i4   - includes 'missing_value' of type integer
c      nc_miss_val_r    - includes 'missing_value' of type real (float)
c      nc_miss_val_d    - includes 'missing_value' of type double
c      nc_dims          - includes the numeric attributes 'scale_factor'
c                         and 'add_offset'
c      nc_range         - includes the twodimensional numeric attribute
c                         'valid_range'

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc


c     The subroutine "nc_char_attrib" writes
c      - the name of a character attribute ('name')
c      - the value of the character attribute ('attrib')
c     to the current netCDF header for the parameter indicated by 'id'.
c     If an error occurs, the name of the parameter ('prmtr') is passed
c     to an error message subroutines which terminates the program.

      subroutine nc_char_attrib(id, name, attrib, prmtr)

      implicit none

      include 'netcdf.inc'
      include 'id.inc'

c     Input:
      integer id
      character*(*) name
      character*(*) attrib
      character*(*) prmtr

c     Local:
      integer nc_status,size_name,size_attrib

c     Function:
      integer str_len


      size_name = str_len(name)
      size_attrib = str_len(attrib)
      nc_status = NF_PUT_ATT_TEXT(nc_id, id, name(1:size_name),
     >                            size_attrib, attrib(1:size_attrib))
      if (nc_status .ne. NF_NOERR)
     >   call handle_err_txt(nc_status, attrib, prmtr, 1)

      return
      end


c     The subroutines "nc_miss_val_X" writes the attribute
c      - 'missing_value' (based on the contents of "missing_values.inc")
c     to the current netCDF header for the parameter indicated by 'id'.
c     If an error occurs, the name of the parameter ('prmtr') is passed
c     to an error message subroutines which terminates the program.

      subroutine nc_miss_val_i2(id, prmtr)

      implicit none

      include 'netcdf.inc'
      include 'id.inc'
      include 'missing_values.inc'

c     Input:
      integer id
      character*(*) prmtr

c     Local:
      integer nc_status


      nc_status = NF_PUT_ATT_INT2(nc_id, id, 'missing_value',
     >                            NF_SHORT, 1, miss_val_i2)
      if (nc_status .ne. NF_NOERR)
     >   call handle_err_txt(nc_status, 'missing_value', prmtr, 2)

      return
      end


      subroutine nc_miss_val_i4(id, prmtr)

      implicit none

      include 'netcdf.inc'
      include 'id.inc'
      include 'missing_values.inc'

c     Input:
      integer id
      character*(*) prmtr

c     Local:
      integer nc_status


      nc_status = NF_PUT_ATT_INT(nc_id, id, 'missing_value',
     >                           NF_INT, 1, miss_val_i4)
      if (nc_status .ne. NF_NOERR)
     >   call handle_err_txt(nc_status, 'missing_value', prmtr, 2)

      return
      end


      subroutine nc_miss_val_r(id, prmtr)

      implicit none

      include 'netcdf.inc'
      include 'id.inc'
      include 'missing_values.inc'

c     Input:
      integer id
      character*(*) prmtr

c     Local:
      integer nc_status


      nc_status = NF_PUT_ATT_REAL(nc_id, id, 'missing_value',
     >                            NF_FLOAT, 1, miss_val_r)
      if (nc_status .ne. NF_NOERR)
     >   call handle_err_txt(nc_status, 'missing_value', prmtr, 2)

      return
      end


      subroutine nc_miss_val_d(id, prmtr)

      implicit none

      include 'netcdf.inc'
      include 'id.inc'
      include 'missing_values.inc'

c     Input:
      integer id
      character*(*) prmtr

c     Local:
      integer nc_status


      nc_status = NF_PUT_ATT_DOUBLE(nc_id, id, 'missing_value',
     >                              NF_DOUBLE, 1, miss_val_d)
      if (nc_status .ne. NF_NOERR)
     >   call handle_err_txt(nc_status, 'missing_value', prmtr, 2)

      return
      end


c     The subroutine "nc_dims" writes the attributes
c      - 'scale_factor' [based on 'scale(1)']
c      - 'add_offset' [based on 'zero(1)']
c     to the current netCDF header for the parameter indicated by 'id'.
c     If an error occurs, the name of the parameter ('prmtr') is passed
c     to an error message subroutines which terminates the program.

      subroutine nc_dims(id, scale, zero, prmtr)

      implicit none

      include 'netcdf.inc'
      include 'id.inc'

c     Input:
      integer id
      real scale(1),zero(1)
      character*(*) prmtr

c     Local:
      integer nc_status


      nc_status = NF_PUT_ATT_REAL(nc_id, id, 'scale_factor',
     >                            NF_FLOAT, 1, scale)
      if (nc_status .ne. NF_NOERR)
     >   call handle_err_txt(nc_status, 'scale_factor', prmtr, 3)

      nc_status = NF_PUT_ATT_REAL(nc_id, id, 'add_offset',
     >                            NF_FLOAT, 1, zero)
      if (nc_status .ne. NF_NOERR)
     >   call handle_err_txt(nc_status, 'add_offset', prmtr, 4)

      return
      end


c     The subroutine "nc_range" writes the attribute
c      - 'valid_range' (based on '[range(1), range(2))]'
c                       as lower and upper limit, respectively)
c     to the current netCDF header for the parameter indicated by 'id'.
c     If an error occurs, the name of the parameter ('prmtr') is passed
c     to an error message subroutines which terminates the program.

      subroutine nc_range(id, range, prmtr)

      implicit none

      include 'netcdf.inc'
      include 'id.inc'

c     Input:
      integer id
      real range(2)
      character*(*) prmtr

c     Local:
      integer nc_status


      nc_status = NF_PUT_ATT_REAL(nc_id, id, 'valid_range',
     >                            NF_FLOAT, 2, range)
      if (nc_status .ne. NF_NOERR)
     >   call handle_err_txt(nc_status, 'valid_range', prmtr, 5)

      return
      end
