
ccc   Subroutines on "nc_errors.f":
ccc    handle_err       - writes netCDF error message, terminates
ccc                       program
ccc    handle_err_txt   - writes netCDF error message with additional
ccc                       information, terminates program
ccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc



c     ********************
c     General description:
c     ********************

c     The subroutine "handle_err" writes a netCDF error message,
c     a number indicating the position in the code where "handle_err"
c     was called, and terminates the program.

c     ****************
c     Input variables:
c     ****************

c      nc_status      (i)  - the netCDF error code
c      err_no         (i)  - an integer value which may indicate
c                             where the error occured; will be printed

c     Above:
c      i  - integer variable [ 4 byte, aka. "long" ]


      subroutine handle_err(nc_status, err_no)

      implicit none
      include 'netcdf.inc'
      integer nc_status,err_no

      if (nc_status .ne. NF_NOERR) then
         print *, NF_STRERROR(nc_status)
         print *, err_no
         stop 'Stopped'
      end if

      return
      end



c     ********************
c     General description:
c     ********************

c     The subroutine "handle_err_txt" writes a netCDF error message,
c     a number indicating the position in the source code where
c     "handle_err_txt" was called, a text which may indicate for
c     which attribute and variable (or dimension) the error occured,
c     and terminates  the program.


c     ****************
c     Input variables:
c     ****************

c      nc_status      (i)  - the netCDF error code
c      attrib         (s)  - the name of the attribute for which the
c                             error occured
c      prmtr          (s)  - the name of the variable (or dimension)
c                             for which the error occured
c      err_no         (i)  - an integer value which may indicate
c                             where the error occured; will be printed

c     Above:
c      i  - integer variable [ 4 byte, aka. "long" ]
c      s  - string           [ character*(*) ]

c      dim            (s)  - the name of the dimension which will be
c                             checked

c     Above:
c      i  - integer variable [ 4 byte, aka. "long" ]
c      s  - string           [ character*(*) ]

      subroutine handle_err_txt(nc_status, attrib, prmtr, err_no)

      implicit none
      include 'netcdf.inc'
      integer nc_status,err_no
      character*(*) prmtr
      character*(*) attrib

      if (nc_status .ne. NF_NOERR) then
         print *, NF_STRERROR(nc_status)
         print *, attrib
         print *, err_no,' ',prmtr
         stop 'Stopped'
      end if

      return
      end
