
ccc   Functions on "strings.f":
ccc    integer str_len  - computes the position of the last non-blank/
ccc                       non-null character in a string
ccc    integer str_pos  - computes the position of a specific character
ccc                       in a string, starting the search from a
ccc                       specified character in the input string,
ccc                       in a specified direction
ccc    character null_chrctr
ccc                     - returns the null character 
ccc
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc



c     ********************
c     General description:
c     ********************

c     The function "str_len" returns the position of the final
c     non-blank/non-null character of 'string'.


c     ****************
c     Input variables:
c     ****************

c      string         (s)  - a character string for which the position
c                             of the final non-blank/non-null'
c                             character is requested

c     Above:
c      s  - string           [ character*(*) ]


      integer function str_len(string)

      implicit none

c     Input:
      character*(*) string

c     Local:
      integer position

c     Function:
      character null_chrctr


      position = len(string)
      do while ((string(position:position) .eq. ' ' .or.
     >           string(position:position) .eq. null_chrctr()) .and.
     >          position .gt. 1)
         position = position - 1
      end do
      if (position .eq. 1 .and. string(1:1) .eq. ' ') position = 0
      str_len = position

      end



c     ********************
c     General description:
c     ********************

c     The function "str_pos" returns the position of a specified
c     character in a (sub-)string, searching from a specified
c     character no. in the string, searching forwards or backwards.
c     in 'string' that matches 'chrctr'. The search is initiated at
c     string position |'start'|, and the search is conducted in
c     positive and negative directions for positive and negative values
c     of 'start', respectively.


c     ****************
c     Input variables:
c     ****************

c      string         (s)  - a character string for which the position
c                             of a specific character is requested
c      start          (i)  - the search for the position in 'string'
c                             will be initiated at |start|, and the
c                             search will be conducted in positive and
c                             negative directions for positive and
c                             negative values of 'start', respectively
c      chrctr         (c)  - the character whose position is requested

c     Above:
c      s  - string           [ character*(*) ]
c      i  - integer variable [ 4 byte, aka. "long" ]
c      c  - character        [ 1 byte character ]


      integer function str_pos(string,start,chrctr)

      implicit none

c     Input:
      integer start
      character chrctr
      character*(*) string

c     Local:
      integer position,terminate,step
      logical got_it

c     Function:
      integer str_len


c     Initialize:
      position = abs(start)
      if (start .gt. 0) then
         terminate = str_len(string)
         step = 1
      else
         terminate = 1
         step = -1
      end if
      if (string(position:position) .eq. chrctr) then
         got_it = .true.
      else
         got_it = .false.
      end if

c     Find 'position' if different from |'start'|:
      do while (.not. got_it .and. position .ne. terminate)
         position = position + step
         if (string(position:position) .eq. chrctr) got_it = .true.
      end do

      if (got_it) then
         str_pos = position
      else
         write(*,*)
         write(*,*)'Warning from the function "str_pos".'
         write(*,*)' The specified character (',chrctr,
     >             ') was not found!'
         write(*,*)'  Searced the (sub-)string:'
         write(*,*)'   ',string(max(1,start):max(-start,terminate))
         write(*,*)'Returning with zero ...'
         write(*,*)
         str_pos = 0
      end if

      end



c     ********************
c     General description:
c     ********************

c     The function "null_chrctr" returns the "null character"
c     (end-of-string mark).

c     IMPORTANT NOTE:
c      This version assumes that the null character can be specified
c      as '\0'. This should work on SGI, SUN and DEC, put could be
c      a problem on other platforms (e.g., IBM).


      character function null_chrctr()

      implicit none

      null_chrctr = '\0'

      end
